<template>
  <section
  :class="{ ['color' + medical.shop_color]: true, ['layout' + medical.shop_style]: true }"
  class="medical">
  <div class="shop-html">
    <div class="shop-body">
      <section
        v-show="medical.shop_style == 1 || medical.shop_style == 2"
        class="wrapper">
        <header>
          <div class="inner">
            <div id="yatlogo">
              <img
                width="98"
                height="81"
                :src="logo"
                id="yatlogoimg">
            </div>
            <div class="contentwidthcontainer">
              <div id="shopinfo">
                <div id="shopname">{{ medical.name }}</div>
                <div class="hometxt">{{ medical.description }}</div>
              </div>
            </div>
          </div>
        </header>
        <div id="navdiv">
          <div class="contentwidthcontainer">
            <div id="menu" v-if="medical.admin">
              <ul id="nav" class="tab-buttons">
                <router-link
                  tag="li"
                  :to="{name: 'medicalmain'}">
                  <a
                    :class="{selected: (this.$route.name === 'medicalmain')}"
                    class="tab">Main Page
                  </a>
                </router-link>
                <router-link
                  tag="li"
                  :to="{name: 'medicaldiagnosis'}">
                  <a
                    :class="{selected: (this.$route.name === 'medicaldiagnosis')}"
                    class="tab">Patient Diagnosis
                  </a>
                </router-link>
                <router-link
                  tag="li"
                  :to="{name: 'medicalaccounting'}">
                  <a
                    :class="{selected: (this.$route.name === 'medicalaccounting')}"
                    class="tab">Accounting
                  </a>
                </router-link>
                <div class="clear"></div>
              </ul>
            </div>
          </div>
        </div>
        <div id="medicalcontentcontainer" class="clearfix">
          <div class="contentwidthcontainer">
            <div id="sidebar">
              <headlines />
              <action-buttons
                :has-swiper="hasSwiper"
                :shop="medical" />
            </div>
            <div id="maincontent">
              <router-view
                @new-patient="getRecentPatients"
                @simple-one="simpleOne"
                @simple-two="simpleTwo"
                @busy-one="busyOne"
                @busy-two="busyTwo"
                :shop="medical"
                :recentPatients="recentPatients"/>
            </div>
          </div>
        </div>
      </section>
    </div>
  </div>
</section>
</template>

<script>
import ShopBaseView from '../shopBase.js';
import Headlines from '../Headlines.vue';
import ActionButtons from '../ActionButtons.vue';

export default {
  extends: ShopBaseView,
  components: {
    Headlines,
    ActionButtons
  },
  data() {
    return {
      logo: app.network.data.shop_logo,
      medical: {},
      hasSwiper: app.computerSettings.swiper,
      recentPatients: []
    }
  },
  methods: {
    getData() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/medical/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.medical = Response;
            app.Message( "Successfully loaded the Medical Center!", "success" );
          })
          .catch( x => app.Message( x.error, "error" ) )
        })
    },
    simpleOne() {
      this.medical.shop_style = 1;
      this.medical.shop_color = 1;
    },
    simpleTwo() {
      this.medical.shop_style = 1;
      this.medical.shop_color = 2;
    },
    busyOne() {
      this.medical.shop_style = 2;
      this.medical.shop_color = 1;
    },
    busyTwo() {
      this.medical.shop_style = 2;
      this.medical.shop_color = 2;
    },
    getRecentPatients() {
      app.session.SetSession()
        .then( () => {
        app.api.Get( "/medical/recentpatients/" + app.session.data.id )
          .then( Response => {
            console.log(Response);
            this.recentPatients = Response;
          })
          .catch( x => app.Message( x.error, "error" ) )
        })
    }
  },
  created: function () {
    this.getData();
    this.getRecentPatients();
  },
  beforeMount: function () {
    this.$router.push({name: 'medicalmain'});
  }
}
</script>
<style lang="less">
  @import '../../shared.less';
</style>

<style lang="less">
.medical.layout1.color1 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Medical Center common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @ekglines: url(/images/shop/medical/medical-ekg-lines.png) right top no-repeat;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() { background-image: @bgimage; background-repeat:no-repeat; background-position:center 0; }
  //color1
  @shoptitlecolor: white;
  @shopinfowidth: 62rem;
  @logoborder: 0.5rem solid #31a0f5;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/medical/medical-bg-1.jpg);
  @bgheader: url(/images/shop/medical/medical-bg-header-main.jpg);
  @navdivbg: linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #101b22;
  @hometxtcolor:#99d3ff;
  @tablebg: url(/images/shop/medical/bg-table-blue.png);

  @import './medicalLayout1.less';
}
</style>

<style lang="less">
.medical.layout1.color2 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Medical Center common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: left;
  @maincontentfloat:right;
  @ekglines: url(/images/shop/medical/medical-ekg-lines.png) right top no-repeat;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;

  .bodyback() { background-image: @bgimage; background-repeat:no-repeat; background-position:center 0; }
  //color2
  @shoptitlecolor: #fcdea4;
  @shopinfowidth: 62rem;
  @logoborder: 0.5rem solid #cab283;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/medical/medical-bg-1.jpg);
  @bgheader: url(/images/shop/medical/medical-bg-header-main.jpg);
  @navdivbg: linear-gradient(to bottom, #d4c09b 0%,#a28f69 100%);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #204a49;
  @hometxtcolor: white;
  @tablebg: url(/images/shop/medical/bg-table-brown.png);

  @import './medicalLayout1.less';
}
</style>

<style lang="less">
.medical.layout2.color1 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * .shop-html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Medical Center common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @clipboardheader: url(/images/shop/medical/medical2-header.png) center top no-repeat;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;
  //linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  //color1
  @shoptitlecolor: #5f5485;
  @shopinfowidth: 62rem;
  @logoborder: 0.5rem solid #71639e;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/medical/medical2-c1bg.jpg);
  @bgheader: url(/images/shop/medical/medical2-bg-header-main.jpg);
  @navdivbg: rgba(0,0,0,.2);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #4d436b;
  @buttonbgcolor:#bab5c2;
  @buttonbordercolor:#e4deed;
  @buttonhoverbg:#958f9d;
  @hometxtcolor:#5f5485;
  @tablebg: url(/images/shop/medical/bg-table-blue-gray.jpg);
  .bodyback() { background:linear-gradient(to bottom, rgba(165,131,215,.2) 0%,rgba(165,131,215,.08) 100%); }

  @import './medicalLayout2.less';
}
</style>

<style lang="less">
.medical.layout2.color2 {
  .clearfix:after { content: "."; display: block; height: 0; clear: both; visibility: hidden; }
  .clearfix { display: inline-block; }
  * html .clearfix { height: 1%; }
  .clearfix { display: block; }

  /* Medical Center common */

  @sidebarcolor: none;
  @shopnametop: 4rem;
  @shopnameleft: 42rem;
  @boxshadow: 0 0.2rem 0.6rem 0rem #555;
  @sidebarfloat: right;
  @maincontentfloat:left;
  @clipboardheader: url(/images/shop/medical/medical2-header.png) center top no-repeat;
  @bgcolor: #b2b2b0;
  @contentborder: 1px solid #ecf4f8;
  @textshadow: #2a6b8f;
  @textshadow2: #d7d7d7;
  @maincontentcolor: #131736;
  //linear-gradient(to bottom, #4b86b2 0%,#366080 100%);
  //color2
  @shoptitlecolor: #315774;
  @shopinfowidth: 62rem;
  @logoborder: 0.5rem solid #305673;
  @shopdesccolor:#227eb1;
  @homemsgcolor:#144a68;
  @bgimage: url(/images/shop/medical/medical2-c2bg.jpg);
  @bgheader: url(/images/shop/medical/medical2-bg-header-main.jpg);
  @navdivbg: rgba(0,0,0,.2);
  @activetabcolor: #fff;
  @navbgcolor: #b2f7be;
  @tabfontcolor: #315673;
  @buttonbgcolor:#97adb6;
  @buttonbordercolor:#bfdbe6;
  @buttonhoverbg:#74909c;
  @hometxtcolor: #315774;
  @tablebg: url(/images/shop/medical/bg-table2-blue.jpg);
  .bodyback() { background-image:linear-gradient(to bottom, rgba(131,191,215,.5) 0%,rgba(131,191,215,.21) 100%); }

  @import './medicalLayout2.less';
}
</style>


